==> catflow_validate-0.3.0.tar.gz: catflow_validate-0.3.0/catflow_validate/cli.py <==
import os
import glob

import click

from catflow_validate.landuse import LanduseClassDef
from catflow_validate.report import Report


@click.group()
def cli():
    pass


@click.command()
@click.option('--filename', '-f', default='./landuseclass.def', help='Filename for the landuse class definition file.')
@click.option('--recursive', '-r', is_flag=True, help="Validate all referenced landuse class parameter files recursively")
@click.option('--verbose', '-v', default=False, is_flag=True, help="Print out verbose information on errors and warnings.")
@click.option('--extended', '-e', default=False, is_flag=True, help="Print an extended report.")
def landuse(filename: str, recursive: bool = False, verbose: bool = False, extended: bool = False) -> int:
    if not os.path.exists(filename):
        click.echo("The landuse class definition file could not be found.")
        return 1
    
    # load the file
    l = LanduseClassDef(filename, recursive=recursive)

    # validate
    valid = l.validate()

    if not verbose:
        if valid:
            click.secho('valid', fg='green')
        else:
            click.secho('invalid', fg='red')
        return 0

    # create the report
    report = Report(landuse=l)
    report.landuse_summary()

    if extended:
        click.echo('')
    report.landuse_details(extended=extended)


@click.command()
@click.option('--input-folder', '-i', default='./', help="CATFLOW input data root folder")
@click.option('--landuse-filename', '-L', default='landuseclass.def', help="Name of the landuse-class definition file")
def report(input_folder: str = './', landuse_filename: str = 'landuseclass.def'):
    # get all files recursively
    filenames = glob.glob(os.path.join(input_folder, '**', '*'), recursive=True)

    # filter for the landuse file
    try:
        filename = next(filter(lambda s: s.endswith(landuse_filename), filenames))
        landuse = LanduseClassDef(filename=filename, basepath=input_folder, recursive=True)
        landuse.validate()
    except Exception:
        landuse = None

    # finally build the report
    report = Report(landuse=landuse)
    report()


# add the commands
cli.add_command(landuse)
cli.add_command(report)


if __name__ == '__main__':
    cli()

==> catflow_validate-0.6.0.tar.gz: catflow_validate-0.6.0/catflow_validate/cli.py <==
import os
import glob

import click

from catflow_validate.landuse import LanduseClassDef
from catflow_validate.soil import SoilsDef
from catflow_validate.report import Report


@click.group()
def cli():
    pass


@click.command()
@click.option('--filename', '-f', default='./landuseclass.def', help='Filename for the landuse class definition file.')
@click.option('--recursive', '-r', is_flag=True, help="Validate all referenced landuse class parameter files recursively")
@click.option('--verbose', '-v', default=False, is_flag=True, help="Print out verbose information on errors and warnings.")
@click.option('--extended', '-e', default=False, is_flag=True, help="Print an extended report.")
def landuse(filename: str, recursive: bool = False, verbose: bool = False, extended: bool = False) -> int:
    if not os.path.exists(filename):
        click.echo("The landuse class definition file could not be found.")
        return 1
    
    # load the file
    l = LanduseClassDef(filename, recursive=recursive)

    # validate
    valid = l.validate()

    if not verbose:
        if valid:
            click.secho('valid', fg='green')
        else:
            click.secho('invalid', fg='red')
        return 0

    # create the report
    report = Report(landuse=l)
    lines = report.landuse_summary()
    report.echo_summary(lines)

    if extended:
        click.echo('')
    report.landuse_details(extended=extended)


@click.command()
@click.option('--filename', '-f', default='./l*_soils.def', help='Filename for the SOIL definition file.')
@click.option('--verbose', '-v', default=False, is_flag=True, help="Print out verbose information on errors and warnings.")
@click.option('--extended', '-e', default=False, is_flag=True, help="Print an extended report.")
@click.option('--omit-warnings', '-w', default=False, is_flag=True, help="If set, Warnings are ignored.")
def soil(filename: str, verbose: bool = False, extended: bool = False, omit_warnings: bool = False) -> int:
    if not os.path.exists(filename):
        click.echo("The soil definition file could not be found")
        return 1
    
    # load the file
    s = SoilsDef(filename, encoding='latin1')

    # single word return
    if not verbose:
        if s.valid(warnings_as_errors=not omit_warnings):
            click.secho('valid', fg='green')
        else:
            click.secho('invalid', fg='red')
        return 0

    # use the report
    report = Report(soil=s)
    lines = report.soil_summary()
    report.echo_summary(lines)

    if extended:
        click.echo('')
        report.soil_details(extended=extended)


@click.command()
@click.option('--input-folder', '-i', default='./', help="CATFLOW input data root folder")
@click.option('--landuse-filename', '-L', default='landuseclass.def', help="Name of the landuse-class definition file")
@click.option('--fmt', default='txt', type=click.Choice(['txt', 'md'], case_sensitive=False), help="Output format of the report")
@click.option('--base-href', type=str, help="Base href path for hyperlinks in the report.")
def report(input_folder: str = './', landuse_filename: str = 'landuseclass.def', fmt: str = 'txt', base_href=None):
    # get all files recursively
    filenames = glob.glob(os.path.join(input_folder, '**', '*'), recursive=True)

    # filter for the landuse file
    #try:
    filename = next(filter(lambda s: s.endswith(landuse_filename), filenames))
    landuse = LanduseClassDef(filename=filename, basepath=input_folder, recursive=True, fmt=fmt, base_href=base_href)
    landuse.validate()
    #except Exception:
    #    print('GOT WRONG')
    #    landuse = None

    # finally build the report
    report = Report(landuse=landuse, fmt=fmt)
    report()


# add the commands
cli.add_command(landuse)
cli.add_command(soil)
cli.add_command(report)


if __name__ == '__main__':
    cli()
